// Importing modules from D3
import {
  select,csv,scaleLinear,scaleTime,extent,axisLeft,axisBottom,line,max
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { 
// Assigning X axis data   
  const xValue = d => d.years; 
  const xAxisLabel = 'years';
// Assigning Y axis data 
  const yValue = d => d.population ;
  const yAxisLabel = 'Population';
  const margin = { top: 40, right: 20, bottom: 38, left: 130 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top-20 - margin.bottom-30;
  
  //  Scale for X axis
 const xScale = scaleTime()
    .domain(extent(data, xValue)) 
    .range([0, innerWidth]) 
    .nice(); //round values out
  
//  Scale for Y axis  
  const yScale = scaleLinear()
    .domain(extent(data, yValue ))
    .range([innerHeight, 0])
    .nice();
    
// Placing the svg element  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(10);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  	
  const yAxisG = g.append('g').call(yAxis);
     
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 6)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);

// Drawing a line
//adding it to svg 
  
  const Draw_Line = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', Draw_Line(data))
};

// Loading CSV data
csv('https://gist.githubusercontent.com/Ramch16/4ecb38b804b06341d193b5b764867ec1/raw/ab33c291dc32d6ab913de9b1057e0de0e476b5bf/Test_ICE6_RAM.csv')
  .then(data => {
    data.forEach(d => {
    	d.population = +d.population;
//Formatting to retrieve year from the date
      d.years = new Date(d.years);
    });

    render(data);
  });